import chalk from 'chalk';
import GitUrlParse from 'git-url-parse';
import path from 'path';
import * as zx from 'zx';
import { insideDir } from '../utils/filesystem.js';
const convertToAuthURL = (url, githubToken) => {
    const parsed = GitUrlParse(url);
    parsed.token = githubToken;
    return GitUrlParse.stringify(parsed, 'https');
};
export const clone = async ({ githubToken, depth, submodules }) => {
    const topLevel = (await zx.$ `git rev-parse --show-toplevel`).stdout.trim();
    for (const submodule of submodules) {
        const submoduleDir = path.join(topLevel, submodule.gitModulePath);
        const submoduleURL = !!githubToken ? convertToAuthURL(submodule.url, githubToken) : submodule.url;
        await zx.$ `rm -rf ${submoduleDir}`.catch(() => {
            /* ignored */
        });
        await zx.$ `mkdir ${submoduleDir}`.catch(() => {
            /* ignored */
        });
        await insideDir(submoduleDir, async () => {
            await zx.$ `git init`;
            try {
                await zx.$ `git remote add origin ${submoduleURL}`;
            }
            catch (_a) {
                await zx.$ `git remote set-url origin ${submoduleURL}`;
            }
            await zx.$ `git fetch origin ${submodule.commitHash} --depth=${depth} --no-tags`;
            await zx.$ `git reset --hard FETCH_HEAD`;
        });
        console.log(`${chalk.green('Clone Success')} Submodule ${chalk.cyan(`${submodule.path}@${submodule.commitHash.slice(0, 7)}`)}`);
    }
};
