import chalk from 'chalk';
import { exit } from 'process';
import * as zx from 'zx';
import { clone } from './commands/clone.js';
import { help } from './commands/help.js';
import { fetchSubmodules } from './utils/submodules.js';
const OPTIONS = {
    '-h': 'help',
    '--help': 'help',
    '-v': 'verbose',
    '--verbose': 'verbose',
    '--all': 'all',
    '--paths': 'paths',
    '--depth': 'depth',
    '--token': 'token',
};
const isKnownOption = (arg) => Object.keys(OPTIONS).includes(arg);
const main = async () => {
    var _a, _b, _c;
    const argv = process.argv.slice(2);
    const parsedOptions = {};
    let current = undefined;
    argv.forEach((arg) => {
        var _a;
        if (isKnownOption(arg)) {
            current = OPTIONS[arg];
            parsedOptions[current] = [];
        }
        else if (!!current) {
            (_a = parsedOptions[current]) === null || _a === void 0 ? void 0 : _a.push(arg);
        }
    });
    if (parsedOptions.help || Object.values(parsedOptions).length === 0) {
        help();
        exit(0);
    }
    zx.$.verbose = !!parsedOptions.verbose;
    let githubToken = '';
    if ((_a = parsedOptions.token) === null || _a === void 0 ? void 0 : _a[0]) {
        [githubToken] = parsedOptions.token;
    }
    else {
        githubToken = process.env.GITHUB_TOKEN || '';
    }
    let depth = 1;
    if ((_b = parsedOptions.depth) === null || _b === void 0 ? void 0 : _b[0]) {
        depth = Number(parsedOptions.depth[0]);
    }
    if (depth < 1) {
        throw new Error('git commit history depth must be greater than 0');
    }
    const specificPaths = (_c = parsedOptions.paths) !== null && _c !== void 0 ? _c : [];
    const submodules = await fetchSubmodules({
        paths: specificPaths.length > 0 ? specificPaths : null,
    });
    await clone({ githubToken, depth, submodules });
};
main().catch((error) => {
    console.error(`${chalk.red(`Error!`)} ${error.message}`);
    exit(1);
});
